@@ -19,8 +19,8 @@ def url_resolves(url):
 def fetch_and_validate_source(source, target):
     response = requests.get(source)
     if response.status_code == 200:
-        if target in str(response.content):
-            return response.content
+        if target in response.text:
+            return response.text
         else:
             raise TargetNotFoundError("Source URL did not contain target URL")
     else:
